library(betareg)
data(GasolineYield)
source("functions_betareg.R")

## Maximum likelihood fit
modelMLbetareg <- betareg(yield ~ batch + temp, data = GasolineYield,
                              hessian = FALSE)
### lDers(modelMLbetareg)$scores
modelML <- improveFit(modelMLbetareg,
                      maxit = 1000, slowit = 1, epsilon = 1e-10)
### modelML$scores



## Bias-corrected fit
modelBC <- BiasCor(modelML)
## Bias-reduced fit using adjustments based on the expected information
modelBRExp <- BiasRed(modelML, maxit = 1000, epsilon = 1e-10,
                      slowit = 1, method = "Expected",
                      fisher = TRUE, keep.history = TRUE)
## Bias-reduced fit using adjustments based on the observed information
modelBRObs <- BiasRed(modelML, maxit = 1000, epsilon = 1e-10,
                      slowit = 1, method = "Observed",
                      fisher = FALSE, keep.history = TRUE)


## The bias-corrected estimates also results in the first iteration of
## modified Fisher scoring for adjustements based on the expected
## information, or in the first iteration of quasi Newton-Raphson for
## adjustments based on the observed information
unlist(modelBC$coefficients) - modelBRExp$history[,2]
unlist(modelBC$coefficients) - modelBRObs$history[,2]
